@@ -1,9 +1,9 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgDatabase.cpp 8087 2009-11-23 11:24:39Z dpage $
-// Copyright (C) 2002 - 2009, The pgAdmin Development Team
-// This software is released under the BSD Licence
+// RCS-ID:      $Id: dlgDatabase.cpp 8187 2010-02-25 21:54:35Z dpage $
+// Copyright (C) 2002 - 2010, The pgAdmin Development Team
+// This software is released under the PostgreSQL Licence
 //
 // dlgDatabase.cpp - PostgreSQL Database Property
 //
@@ -591,8 +591,8 @@ wxString dlgDatabase::GetSql()
             {
                 sql += wxT("ALTER DATABASE ") + qtIdent(name)
                     +  wxT(" SET ") + newVar
-                    +  wxT("=") + newVal
-                    +  wxT(";\n");
+                    +  wxT("='") + newVal
+                    +  wxT("';\n");
             }
         }
         
@@ -659,8 +659,8 @@ wxString dlgDatabase::GetSql2()
         {
             sql += wxT("ALTER DATABASE ") + qtIdent(name)
                 +  wxT(" SET ") + lstVariables->GetText(pos)
-                +  wxT("=") + lstVariables->GetText(pos, 1)
-                +  wxT(";\n");
+                +  wxT("='") + lstVariables->GetText(pos, 1)
+                +  wxT("';\n");
         }
     }
 
