@@ -1,9 +1,9 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgFunction.cpp 8063 2009-10-06 02:45:04Z dpage $
-// Copyright (C) 2002 - 2009, The pgAdmin Development Team
-// This software is released under the BSD Licence
+// RCS-ID:      $Id: dlgFunction.cpp 8187 2010-02-25 21:54:35Z dpage $
+// Copyright (C) 2002 - 2010, The pgAdmin Development Team
+// This software is released under the PostgreSQL Licence
 //
 // dlgFunction.cpp - PostgreSQL Function Property
 //
@@ -985,8 +985,8 @@ wxString dlgFunction::GetSql()
             {
                 sql += wxT("ALTER FUNCTION ") + name
                     +  wxT(" SET ") + newVar
-                    +  wxT("=") + newVal
-                    +  wxT(";\n");
+                    +  wxT("='") + newVal
+                    +  wxT("';\n");
             }
         }
         
