@@ -1,9 +1,9 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgRole.cpp 7758 2009-03-26 20:49:59Z dpage $
-// Copyright (C) 2002 - 2009, The pgAdmin Development Team
-// This software is released under the BSD Licence
+// RCS-ID:      $Id: dlgRole.cpp 8187 2010-02-25 21:54:35Z dpage $
+// Copyright (C) 2002 - 2010, The pgAdmin Development Team
+// This software is released under the PostgreSQL Licence
 //
 // dlgRole.cpp - PostgreSQL Role Property
 //
@@ -274,6 +274,13 @@ void dlgRole::OnOK(wxCommandEvent &ev)
 void dlgRole::OnChangeCal(wxCalendarEvent &ev)
 {
 	CheckChange();
+
+    bool timEn=ev.GetDate().IsValid();
+    timValidUntil->Enable(timEn);
+    if (!timEn)
+        timValidUntil->SetTime(wxDefaultDateTime);
+    else
+        timValidUntil->SetTime(wxDateTime::Today());
 }
 
 
@@ -285,6 +292,8 @@ void dlgRole::OnChangeDate(wxDateEvent &ev)
     timValidUntil->Enable(timEn);
     if (!timEn)
         timValidUntil->SetTime(wxDefaultDateTime);
+    else
+        timValidUntil->SetTime(wxDateTime::Today());
 }
 
 void dlgRole::OnChangeSpin(wxSpinEvent &ev)
@@ -738,15 +747,15 @@ wxString dlgRole::GetSql()
         {
             sql += wxT("ALTER ROLE ") + qtIdent(name)
                 +  wxT(" SET ") + newVar
-                +  wxT("=") + newVal
-                +  wxT(";\n");
+                +  wxT("='") + newVal
+                +  wxT("';\n");
         }
     }
     
     // check for removed vars
     for (pos=0 ; pos < (int)vars.GetCount() ; pos++)
     {
-        sql += wxT("ALTER Role ") + qtIdent(name)
+        sql += wxT("ALTER ROLE ") + qtIdent(name)
             +  wxT(" RESET ") + vars.Item(pos).BeforeFirst('=')
             + wxT(";\n");
     }
