@@ -1,9 +1,9 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: dlgUser.cpp 7758 2009-03-26 20:49:59Z dpage $
-// Copyright (C) 2002 - 2009, The pgAdmin Development Team
-// This software is released under the BSD Licence
+// RCS-ID:      $Id: dlgUser.cpp 8187 2010-02-25 21:54:35Z dpage $
+// Copyright (C) 2002 - 2010, The pgAdmin Development Team
+// This software is released under the PostgreSQL Licence
 //
 // dlgUser.cpp - PostgreSQL User Property
 //
@@ -199,6 +199,13 @@ wxString dlgUser::GetHelpPage() const
 void dlgUser::OnChangeCal(wxCalendarEvent &ev)
 {
 	CheckChange();
+
+    bool timEn=ev.GetDate().IsValid();
+    timValidUntil->Enable(timEn);
+    if (!timEn)
+        timValidUntil->SetTime(wxDefaultDateTime);
+    else
+        timValidUntil->SetTime(wxDateTime::Today());
 }
 
 
@@ -210,6 +217,8 @@ void dlgUser::OnChangeDate(wxDateEvent &ev)
     timValidUntil->Enable(timEn);
     if (!timEn)
         timValidUntil->SetTime(wxDefaultDateTime);
+    else
+        timValidUntil->SetTime(wxDateTime::Today());
 }
 
 void dlgUser::OnChangeSpin(wxSpinEvent &ev)
@@ -532,8 +541,8 @@ wxString dlgUser::GetSql()
         {
             sql += wxT("ALTER USER ") + qtIdent(name)
                 +  wxT(" SET ") + newVar
-                +  wxT("=") + newVal
-                +  wxT(";\n");
+                +  wxT("='") + newVal
+                +  wxT("';\n");
         }
     }
     
