@@ -1,9 +1,9 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: frmMain.cpp 8104 2009-12-03 09:43:11Z guillaume $
-// Copyright (C) 2002 - 2009, The pgAdmin Development Team
-// This software is released under the BSD Licence
+// RCS-ID:      $Id: frmMain.cpp 8187 2010-02-25 21:54:35Z dpage $
+// Copyright (C) 2002 - 2010, The pgAdmin Development Team
+// This software is released under the PostgreSQL Licence
 //
 // frmMain.cpp - The main form
 //
@@ -916,12 +916,12 @@ int frmMain::ReconnectServer(pgServer *server, bool restore)
 
             server->ShowTreeDetail(browser);
 
+            browser->Freeze();
             if (restore && server->GetRestore())
-            {
-                browser->Freeze();
                 item=RestoreEnvironment(server);
-                browser->Thaw();
-            }
+            else
+                item = server->GetId();
+            browser->Thaw();
 
             if (item)
             {
@@ -931,6 +931,7 @@ int frmMain::ReconnectServer(pgServer *server, bool restore)
                 browser->Expand(item);
                 browser->EnsureVisible(item);
             }
+
             if (item)
                 EndMsg(true);
             else
