@@ -34,9 +34,9 @@
 
 typedef struct ScanKeyword
 {
-	const char *name;			/* in lower case */
-	int		value;			/* grammar's token code */
-	int		category;		/* see codes above */
+    const char *name;			/* in lower case */
+    int		value;			/* grammar's token code */
+    int		category;		/* see codes above */
 } ScanKeyword;
 
 extern const ScanKeyword *ScanKeywordLookup(const char *text);
@@ -437,6 +437,21 @@ enum yytokentype {
  POSTFIXOP = 643,
  UMINUS = 644,
  TYPECAST = 645,
+ CTYPE=646,
+ WINDOW=647,
+
+ /* The following additions are unreserved keywords for autovacuum settings */
+ AUTOVACUUM_E=700,
+ AUTOVACUUM_V_TH=701,
+ AUTOVACUUM_A_TH=702,
+ AUTOVACUUM_V_SC_F=703,
+ AUTOVACUUM_A_SC_F=704,
+ AUTOVACUUM_V_COST_D=705,
+ AUTOVACUUM_V_COST_L=705,
+ AUTOVACUUM_F_MIN_AGE=706,
+ AUTOVACUUM_F_MAX_AGE=707,
+ AUTOVACUUM_F_TBL_AGE=707,
+ FILLFACTOR=707,
 
  /* The following additions are keywords in EnterpriseDB */
  CONNECT_EDB = 800,
@@ -457,7 +472,12 @@ enum yytokentype {
  RAW_EDB = 815,
  RETURN_EDB = 816,
  SYSDATE_EDB = 817,
- SYSTIMESTAMP_EDB = 818
+ SYSTIMESTAMP_EDB = 818,
+
+ /* The following additions are keywords in Greenplum Database */
+ DISTRIBUTED_GP = 900,
+ LOG_P_GP = 901
+
 };
 
 #endif   /* KEYWORDS_H */
