@@ -1,9 +1,9 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgDatabase.cpp 7975 2009-07-20 17:09:27Z guillaume $
-// Copyright (C) 2002 - 2009, The pgAdmin Development Team
-// This software is released under the BSD Licence
+// RCS-ID:      $Id: pgDatabase.cpp 8187 2010-02-25 21:54:35Z dpage $
+// Copyright (C) 2002 - 2010, The pgAdmin Development Team
+// This software is released under the PostgreSQL Licence
 //
 // pgDatabase.cpp - PostgreSQL Database
 //
@@ -365,7 +365,7 @@ wxString pgDatabase::GetSql(ctlTree *browser)
         size_t i;
         for (i=0 ; i < variables.GetCount() ; i++)
             sql += wxT("ALTER DATABASE ") + GetQuotedFullIdentifier()
-                +  wxT(" SET ") + variables.Item(i) + wxT(";\n");
+                + wxT(" SET ") + variables.Item(i).BeforeFirst('=') + wxT("='") + variables.Item(i).AfterFirst('=') + wxT("';\n");
 
 		if (myConn)
 		{
