@@ -1,9 +1,9 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgFunction.cpp 8042 2009-09-24 17:04:37Z guillaume $
-// Copyright (C) 2002 - 2009, The pgAdmin Development Team
-// This software is released under the BSD Licence
+// RCS-ID:      $Id: pgFunction.cpp 8187 2010-02-25 21:54:35Z dpage $
+// Copyright (C) 2002 - 2010, The pgAdmin Development Team
+// This software is released under the PostgreSQL Licence
 //
 // pgFunction.cpp - function class
 //
@@ -142,7 +142,7 @@ wxString pgFunction::GetSql(ctlTree *browser)
         size_t i;
         for (i=0 ; i < configList.GetCount() ; i++)
             sql += wxT("\nALTER FUNCTION ") + qtSig
-                +  wxT(" SET ") + configList.Item(i) + wxT(";");
+                + wxT(" SET ") + configList.Item(i).BeforeFirst('=') + wxT("='") + configList.Item(i).AfterFirst('=') + wxT("';\n");
 
         sql += wxT("\n")
             +  GetOwnerSql(8, 0, wxT("FUNCTION ") + qtSig)
@@ -593,6 +593,8 @@ pgFunction *pgFunctionFactory::AppendFunctions(pgObject *obj, pgSchema *schema,
                             if (argDefValArray[currINindex++] != wxT("-"))
                                 function->iAddArgDef(argDefValArray[currINindex-1]);
                         }
+                        else
+                            function->iAddArgDef(wxEmptyString);
                     }
                     else if(function->GetArgModesArray()[index] == wxT("TABLE"))
                     {
@@ -603,7 +605,8 @@ pgFunction *pgFunctionFactory::AppendFunctions(pgObject *obj, pgSchema *schema,
                             strReturnTableArgs += strName + wxT(" ");
                         strReturnTableArgs += function->GetArgTypesArray()[index];
                     }
-                    function->iAddArgDef(wxEmptyString);
+                    else
+                        function->iAddArgDef(wxEmptyString);
                 }
             }
 
