@@ -1,9 +1,9 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgRole.cpp 7917 2009-06-11 11:07:22Z dpage $
-// Copyright (C) 2002 - 2009, The pgAdmin Development Team
-// This software is released under the BSD Licence
+// RCS-ID:      $Id: pgRole.cpp 8187 2010-02-25 21:54:35Z dpage $
+// Copyright (C) 2002 - 2010, The pgAdmin Development Team
+// This software is released under the PostgreSQL Licence
 //
 // pgRole.cpp - PostgreSQL Role
 //
@@ -105,7 +105,7 @@ wxString pgRole::GetSql(ctlTree *browser)
         for (index=0 ; index < configList.GetCount() ; index++)
         {
             sql += wxT("ALTER ROLE ") + GetQuotedIdentifier()
-                + wxT(" SET ") + configList.Item(index) + wxT(";\n");
+                + wxT(" SET ") + configList.Item(index).BeforeFirst('=') + wxT("='") + configList.Item(index).AfterFirst('=') + wxT("';\n");
         }
         for (index=0 ; index < rolesIn.GetCount() ; index++)
         {
