@@ -1,9 +1,9 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAdmin III - PostgreSQL Tools
-// RCS-ID:      $Id: pgUser.cpp 7813 2009-04-16 11:02:13Z dpage $
-// Copyright (C) 2002 - 2009, The pgAdmin Development Team
-// This software is released under the BSD Licence
+// RCS-ID:      $Id: pgUser.cpp 8187 2010-02-25 21:54:35Z dpage $
+// Copyright (C) 2002 - 2010, The pgAdmin Development Team
+// This software is released under the PostgreSQL Licence
 //
 // pgUser.cpp - PostgreSQL User
 //
@@ -64,7 +64,7 @@ wxString pgUser::GetSql(ctlTree *browser)
         for (index=0 ; index < configList.GetCount() ; index++)
         {
             sql += wxT("ALTER USER ") + GetQuotedIdentifier()
-                + wxT(" SET ") + configList.Item(index) + wxT(";\n");
+                + wxT(" SET ") + configList.Item(index).BeforeFirst('=') + wxT("='") + configList.Item(index).AfterFirst('=') + wxT("';\n");
         }
         for (index=0 ; index < groupsIn.GetCount() ; index++)
             sql += wxT("ALTER GROUP ") + qtIdent(groupsIn.Item(index))
